==> haskell-strict-0.3.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-7ZEebv7EabCEjNWrS66TpZ
key: strict-0.3.2-7ZEebv7EabCEjNWrS66TpZ
license: BSD3
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
indefinite: False
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
abi: 4518eff838eef304fcf7fcf40a435e3c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/strict-0.3.2
hs-libraries: HSstrict-0.3.2-7ZEebv7EabCEjNWrS66TpZ
depends:
    array-0.5.2.0 base-4.10.0.0
abi-depends: array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-strict-0.3.2-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-strict.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: strict
version: 0.3.2
id: strict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
key: strict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
license: BSD3
copyright: (c) 2006-2007 by Roman Leshchinskiy
maintainer: Don Stewart <dons@galois.com>
homepage: http://www.cse.unsw.edu.au/~rl/code/strict.html
synopsis: Strict data types and String IO.
description:
    This package provides strict versions of some standard Haskell data
    types (pairs, Maybe and Either). It also contains strict IO
    operations.
category: Data, System
author: Roman Leshchinskiy <rl@cse.unsw.edu.au>
exposed: True
indefinite: False
exposed-modules:
    Data.Strict Data.Strict.Either Data.Strict.Maybe Data.Strict.Tuple
    System.IO.Strict
abi: 3d5fec282558d1526e02739f39548bf2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/strict-0.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/strict-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/strict-0.3.2
hs-libraries: HSstrict-0.3.2-1XGU2LPrqRE7Qw1PnSNhY5
depends:
    array-0.5.2.0 base-4.10.1.0
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-strict/html/strict.haddock
haddock-html: /usr/share/doc/haskell-strict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
